@@ -264,22 +264,29 @@ find_response (AdwAlertDialog *self,
   return g_hash_table_lookup (priv->id_to_response, id);
 }
 
-static void
-button_clicked_cb (ResponseInfo *info)
+
+static inline void
+emit_response (AdwAlertDialog *self, GQuark response)
 {
-  AdwAlertDialog *self = info->dialog;
   AdwAlertDialogPrivate *priv = adw_alert_dialog_get_instance_private (self);
 
   g_object_ref (self);
   priv->block_close_response = TRUE;
 
   adw_dialog_close (ADW_DIALOG (self));
-  g_signal_emit (self, signals[SIGNAL_RESPONSE], info->id, g_quark_to_string (info->id));
+  g_signal_emit (self, signals[SIGNAL_RESPONSE], response, g_quark_to_string (response));
 
   priv->block_close_response = FALSE;
   g_object_unref (self);
 }
 
+
+static void
+button_clicked_cb (ResponseInfo *info)
+{
+  emit_response (info->dialog, info->id);
+}
+
 static GtkWidget *
 create_response_button (AdwAlertDialog *self,
                         ResponseInfo   *info)
@@ -972,10 +979,13 @@ adw_alert_dialog_class_init (AdwAlertDialogClass *klass)
    *
    * The response ID of the default response.
    *
-   * If set, pressing <kbd>Enter</kbd> will activate the corresponding button.
+   * The button corresponding to this response will be set as the default widget
+   * of the dialog.
    *
-   * If set to `NULL` or a non-existent response ID, pressing <kbd>Enter</kbd>
-   * will do nothing.
+   * If not set, the default widget will not be set, and the last added response
+   * will be focused by default.
+   *
+   * See [property@Dialog:default-widget].
    *
    * Since: 1.5
    */
@@ -1833,14 +1843,14 @@ adw_alert_dialog_set_extra_child (AdwAlertDialog *self,
   g_return_if_fail (ADW_IS_ALERT_DIALOG (self));
   g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   priv = adw_alert_dialog_get_instance_private (self);
 
   if (child == priv->child)
     return;
 
+  if (child)
+    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
+
   priv->child = child;
   adw_bin_set_child (ADW_BIN (priv->child_bin), child);
   gtk_widget_set_visible (priv->child_bin, child != NULL);
@@ -2309,10 +2319,13 @@ adw_alert_dialog_get_default_response (AdwAlertDialog *self)
  *
  * Sets the ID of the default response of @self.
  *
- * If set, pressing <kbd>Enter</kbd> will activate the corresponding button.
+ * The button corresponding to this response will be set as the default widget
+ * of @self.
  *
- * If set to `NULL` or to a non-existent response ID, pressing <kbd>Enter</kbd>
- * will do nothing.
+ * If not set, the default widget will not be set, and the last added response
+ * will be focused by default.
+ *
+ * See [property@Dialog:default-widget].
  *
  * Since: 1.5
  */
@@ -2447,8 +2460,9 @@ choose_cancelled_cb (GCancellable *cancellable,
                      GTask        *task)
 {
   AdwAlertDialog *self = g_task_get_source_object (task);
+  AdwAlertDialogPrivate *priv = adw_alert_dialog_get_instance_private (self);
 
-  choose_response_cb (self, adw_alert_dialog_get_close_response (self), task);
+  emit_response (self, priv->close_response);
 }
 
 /**
